/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: CMIEventComponent.java 2122 2008-09-27 09:41:35Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.cmi.event;

import org.ow2.util.component.api.Component;
import org.ow2.util.event.api.IEventDispatcher;

/**
 * Interface of the CMI event component.
 * @author Loris Bouzonnet
 */
public interface CMIEventComponent extends Component {

    /**
     * Register a new CMI managed object.<br>
     * If a CMI managed object with the same id is already registered, it will be unregistered first.
     * @param object The CMI managed object to register.
     * @param dispatcher The event dispatcher for this CMI managed object.
     */
    void registerCMIManagedObject(CMIManagedObject object, IEventDispatcher dispatcher);

    /**
     * Unregister a CMI managed object.
     * @param object The CMI managed object to unregister.
     */
    void unregisterCMIManagedObject(CMIManagedObject object);

    /**
     * Register a new event listener.<br>
     * The listener will automatically be register with each dispatcher matching his filter.
     * @param eventListener The listener to register.
     */
    void registerEventListener(CMIEventListener eventListener);

    /**
     * Unregister an event listener.
     * @param eventListener The listener to unregister.
     */
    void unregisterEventListener(CMIEventListener eventListener);

}
